"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var colors_1 = require("./colors");
exports.ColorPalette = colors_1.ColorPalette;
class BufferedOutput {
    constructor(dataStream, lineWrapper, flushTimeout = 250) {
        this.flushTimeout = 250;
        this._lineBuffer = [];
        this._bufferTimeout = null;
        this.dataStream = dataStream;
        this.flushTimeout = flushTimeout;
        this.lineWrapper = lineWrapper;
        this.dataStream.on("data", this.handleData.bind(this));
        this.dataStream.on("close", this.flush.bind(this));
    }
    handleData(data) {
        data
            .toString()
            .trim()
            .split(/\n/g)
            .map(this.lineWrapper.bind(this))
            .forEach(l => this._lineBuffer.push(l));
        clearTimeout(this._bufferTimeout);
        if (this._lineBuffer.length > BufferedOutput.MAX_BUFFER_LINES) {
            this.flush();
            return;
        }
        this._bufferTimeout = setTimeout(this.flush.bind(this), this.flushTimeout);
    }
    flush() {
        if (!this._lineBuffer.length) {
            return;
        }
        console.log(this._lineBuffer.join("\n"));
        this._lineBuffer = [];
    }
    done() {
        clearTimeout(this._bufferTimeout);
        this.flush();
    }
}
BufferedOutput.MAX_BUFFER_LINES = 10;
exports.BufferedOutput = BufferedOutput;
