#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// vim: ft=typescript
const executor_1 = require("./executor");
const cmdname_color_1 = require("./canned-wrappers/cmdname-color");
const firstarg_color_1 = require("./canned-wrappers/firstarg-color");
const timestamp_color_1 = require("./canned-wrappers/timestamp-color");
const pid_color_1 = require("./canned-wrappers/pid-color");
const npmcmd_color_1 = require("./canned-wrappers/npmcmd-color");
const lineWrappers = {
    cmdname: cmdname_color_1.lineWrapper,
    firstarg: firstarg_color_1.lineWrapper,
    timestamp: timestamp_color_1.lineWrapper,
    pid: pid_color_1.lineWrapper,
    npmcmd: npmcmd_color_1.lineWrapper
};
const argv = require("yargs").argv;
if (argv._.length < 1) {
    console.log(`
llexec - run arbitrary commands in parallel

llexec is designed to take a list of commands, run them in parallel, and perform
output buffering on the results so the output is human-readable.

usage:
  llexec [-w line-prefixers] cmd [, cmd, [...]]

  possible line-prefixers:
    cmdname:    the name of the command
    npmcmd:     the 'npm run' task that was executed
    firstarg:   the first argument (useful for build tools)
    timestamp:  the timestamp when the line was printed
    pid:        the PID of the process printing the line

examples:

  llexec -w cmdname 'tsc -p src/' 'scss -w scss/'
  llexec -w firstarg 'make module1' 'make module2'
`);
    process.exit(1);
}
const subcommands = argv._.map(commandString => {
    commandString = commandString.replace(/:::\s*/, "");
    return { command: commandString };
});
const instance = new executor_1.Executor(lineWrappers[argv.w]);
instance
    .run(subcommands)
    .then(function () {
    process.exit(0);
})
    .catch(function (failedJobs) {
    failedJobs.forEach(j => console.error(`[llexec: (${process.pid}) job failed]: ${j.command}`));
    instance.killall();
    process.exit(1);
});
